import numpy as np
from simtk.openmm.app import CharmmPsfFile 
import mdtraj as md
from rdf import *
from util import *

# update the psf
psf_file= "/u/alanyu/plant/structures/plant3.psf"

psf = CharmmPsfFile(psf_file)

# update the first and last trajectory indexes
# change blocksize (number of trajs per block) if needed
blocksize = 5
first = 101
last = 105

# update your template of trajectory files. They don't have to be re-centered
traj_template = '/gs-scratch/mbs/alanyu/plant/w3-2/trj/dyn{}.dcd'

# update your two atom selections
sito_plpc_rdf = RDF(
    psf, 'plpc_sito', ["resname SITO and name O3", "resname PLPC and name P"], 
    r_range=(0, 2), dimension=2, separate_leaflet=True
)

# update the crd to a centered configuration,
# it might be your step5_assembly.crd or
# your output from extract.inp
up, low = find_up_low_from_crd('/u/alanyu/plant/structures/plant3.crd')

for i in range(first, last + 1):
    trj = md.load_dcd(traj_template.format(i), top=psf_file)
    sito_plpc_rdf(
        trj,
        first_trj_index=first,
        up_low_recipe={'explicit_grouping': (up, low)}, 
        save_blocks_interval=blocksize,
        save_to='./data'
    )
