import numpy as np
from simtk.openmm.app import CharmmPsfFile 
import mdtraj as md
from rdf import *

# update the psf
psf_file= "/u/alanyu/plant/structures/plant3.psf"

# update this number, if you are having a symmetric membrane,
# this is just the half of your membrane atoms.
last_atom_index_upper = 7098

psf = CharmmPsfFile(psf_file)

# update the first and last trajectory indexes
# change blocksize (number of trajs per block) if needed
blocksize = 5
first = 101
last = 105

# update your template of trajectory files. They don't have to be re-centered
traj_template = '/gs-scratch/mbs/alanyu/plant/w3-2/trj/dyn{}.dcd'

# update your two atom selections
sito_plpc_rdf = RDF(
    psf, 'plpc_sito', ["resname SITO and name O3", "resname PLPC and name P"], 
    r_range=(0, 2), dimension=2, separate_leaflet=True
)

for i in range(first, last + 1):
    trj = md.load_dcd(traj_template.format(i), top=psf_file)
    sito_plpc_rdf(
        trj,
        first_trj_index=first,
        up_low_recipe={'hard_border': last_atom_index_upper}, 
        # the number above is found from psf for separating upper & lower,
        # doesn't work well with membrane built from CHARMM-GUI containing
        # Glycolipids (maybe more restrictions).
        save_blocks_interval=blocksize,
        save_to='./data'
    )

