from clustering import *
from util import *


# change psf file name
psf = '/u/alanyu/plant/structures/plant3.psf'

# use a (re-)centered crd
# it might be your step5_assembly.crd or
# your output from extract.inp
up, low = find_up_low_from_crd('/u/alanyu/plant/structures/plant3.crd')

# change residue names and their types
# 'g': glycerolipids; 'c': sterols; 's': sphingo or cerimides.
cls = ClusterLip(
    psf_file=psf,
    top_res_info=[
        ('SITO', 'c.sito'), ('PLPC', 'g.pc'), ('DLIPE', 'g.pe'),
        ('CET160', 's.cer'), ('CET161', 's.cer')
    ],
    bot_res_info=[
        ('SITO', 'c.sito'), ('PLPC', 'g.pc'), ('DLIPE', 'g.pe'),
        ('PNPG', 'g.pg'), ('PLPI', 'g.pi'), ('DLIPS', 'g.ps')
    ],
    leaflet_recipe={'explicit_grouping': (up, low)},
    # update min lipids to form a cluster if needed
    min_lipids=3,
    # add pair specific if needed
    clfix={
        'sito-pc': 0.44, 'sito-pe': 0.44, 'sito-pg': 0.44, 
        'sito-pi': 0.44, 'sito-ps': 0.44, 'sito-cer': 0.36
    }
)

# update the first/last trajectory indexes you want to analyze
first=101
last=105

# update the traj template, {} replaces the index of traj
traj_template = '/gs-scratch/mbs/alanyu/plant/w3-2/trj/dyn{}.dcd'

for i in range(first, last + 1):
    traj = md.load_dcd(traj_template.format(i), top=psf)
    cls(traj, save_labels=True, first_traj_index=first)

# this number can be changed to allow 
# different max in the histogram of cluster size
cls.plot_and_save(max_size=20)

cls.analyze_more(first_traj_index=first, last_traj_index=last)
