from clustering import *
from util import *


# change psf file name
psf = '/u/alanyu/plant/structures/plant3.psf'

# use a (re-)centered crd
# it might be your step5_assembly.crd or
# your output from extract.inp
up, low = find_up_low_from_crd('/u/alanyu/plant/structures/plant3.crd')

# change residue names and their types
# 'g': glycerolipids; 'c': sterols; 's': sphingo or cerimides.
cls = ClusterLip(
    psf_file=psf,
    top_res_info=[
        ('SITO', 'c.sito'), ('PLPC', 'g.pc'), ('DLIPE', 'g.pe'),
        ('CET160', 's.cer'), ('CET161', 's.cer')
    ],
    bot_res_info=[
        ('SITO', 'c.sito'), ('PLPC', 'g.pc'), ('DLIPE', 'g.pe'),
        ('PNPG', 'g.pg'), ('PLPI', 'g.pi'), ('DLIPS', 'g.ps')
    ],
    # update min lipids to form a cluster if needed
    min_lipids=3,
    leaflet_recipe={'explicit_grouping': (up, low)},
    # add pair specific if needed
    clfix={
        'sito-pc': 0.44, 'sito-pe': 0.44, 'sito-pg': 0.44, 
        'sito-pi': 0.44, 'sito-ps': 0.44, 'sito-cer': 0.36
    }
)

# update the first/last trajectory indexes you want to analyze
first=101
last=105

# update the traj template, {} replaces the index of traj
traj_template = '/gs-scratch/mbs/alanyu/plant/w3-2/trj/dyn{}.dcd'

# Change the inverval (5) to have sparser/denser output.
# 5 here means save one snapshot (for both upper and lower)
# for every 5 trajectories (the last traj gets used).
# Note the "frame" can be set to any number smaller than
# the frame number in each trajectory, though it is usually
# set to the last frame.
# "edge" controls the range of the plot (please use 1~3).
# 1.5 means the edge of the plot area is 1.5 * sim.box.edge.
# "addlabel" controls x/y labeling, you might want to remove labels
# (set to False) if you want to combine plots and add shared labels
# later on in some graphic software.
# "highcontrast" controls the color of lipids not in a frame, use "True"
# leads to grey used for these lipids. "False" leads to same coloring as
# those in cluster but non-fill circles.
# * Colors of different lipid types are controlled 
# in clustering.py (first function in that code).
for i in range(first, last + 1, 5):
    traj = md.load_dcd(traj_template.format(i), top=psf)
    cls.write_xy(traj, itraj=i+5-1, frame=1000)
    cls.plot_cluster(itraj=i+5-1, frame=1000, edge=1.5, addlabel=True, highcontrast=False)

